/* $Id: options.c,v 1.4 2007/01/17 15:41:56 nanard Exp $ */
/* MiniUPnP project
 * http://miniupnp.free.fr/ or http://miniupnp.tuxfamily.org/
 * author: Ryan Wagoner
 * (c) 2006 Thomas Bernard 
 * This software is subject to the conditions detailed
 * in the LICENCE file provided within the distribution */

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <ctype.h>
#include "options.h"

struct option * ary_options = NULL;
int num_options = 0;

int
readoptionsfile(const char * fname)
{
	FILE *hfile = NULL;
	char buffer[1024];
	char *equals;
	char *name;
	char *value;
	char *t;

	if(!fname || (strlen(fname) == 0))
		return -1;

	memset(buffer, 0, sizeof(buffer));

#ifdef DEBUG
	printf("Reading configuration from file %s\n", fname);
#endif
	if(!(hfile = fopen(fname, "r")))
		return -1;

	if(ary_options != NULL)
	{
		free(ary_options);
		num_options = 0;
	}

	while(fgets(buffer, sizeof(buffer), hfile))
	{
		t = strchr(buffer, '\n'); 
		if(t)
		{
			*t = '\0';
			t--;
			while(isspace(*t))
			{
				*t = '\0';
				t--;
			}
		}
       
		/* skip leading whitespaces */
		name = buffer;
		while(isspace(*name))
			name++;
		if(name[0] == '#') continue;
		if(!(equals = strchr(name, '='))) continue;
		/* remove ending whitespaces */
		for(t=equals-1; t>name && isspace(*t); t--)
			*t = '\0';

		*equals = '\0';
		value = equals+1;
		/* skip leading whitespaces */
		while(isspace(*value))
			value++;

		num_options += 1;
		ary_options = (struct option *) realloc(ary_options, num_options * sizeof(struct option));

		strncpy(ary_options[num_options-1].name, name, MAX_OPTION_NAME_LEN);
		strncpy(ary_options[num_options-1].value, value, MAX_OPTION_VALUE_LEN);

		/*fprintf(stderr, "found option: '%s'='%s'\n", name, value);*/
	}
	
	fclose(hfile);
	
	return 0;
}

void
freeoptions(void)
{
	if(ary_options)
	{
		free(ary_options);
		ary_options = NULL;
		num_options = 0;
	}
}

